pub struct EgmSensor {
pub header: Option<EgmHeader>,
pub planned: Option<EgmPlanned>,
pub speed_ref: Option<EgmSpeedRef>,
}Expand description
Robot controller inbound message, sent from sensor to the controller during position guidance
Fields
header: Option<EgmHeader>planned: Option<EgmPlanned>speed_ref: Option<EgmSpeedRef>Implementations
Sourceimpl EgmSensor
impl EgmSensor
Sourcepub fn joint_target(
sequence_number: u32,
joints: impl Into<EgmJoints>,
time: impl Into<EgmClock>,
) -> Self
pub fn joint_target( sequence_number: u32, joints: impl Into<EgmJoints>, time: impl Into<EgmClock>, ) -> Self
Create a sensor message containing a joint space target.
The header timestamp is created from the time parameter.
Sourcepub fn joint_target_with_speed(
sequence_number: u32,
joints: impl Into<EgmJoints>,
speed: impl Into<EgmJoints>,
time: impl Into<EgmClock>,
) -> Self
pub fn joint_target_with_speed( sequence_number: u32, joints: impl Into<EgmJoints>, speed: impl Into<EgmJoints>, time: impl Into<EgmClock>, ) -> Self
Create a sensor message containing a joint space target and a joint space speed reference.
The header timestamp is created from the time parameter.
Sourcepub fn pose_target(
sequence_number: u32,
pose: impl Into<EgmPose>,
time: impl Into<EgmClock>,
) -> Self
pub fn pose_target( sequence_number: u32, pose: impl Into<EgmPose>, time: impl Into<EgmClock>, ) -> Self
Create a sensor message containing a 6-DOF pose target.
The header timestamp is created from the time parameter.
Sourcepub fn pose_target_with_speed(
sequence_number: u32,
pose: impl Into<EgmPose>,
speed: impl Into<EgmCartesianSpeed>,
time: impl Into<EgmClock>,
) -> Self
pub fn pose_target_with_speed( sequence_number: u32, pose: impl Into<EgmPose>, speed: impl Into<EgmCartesianSpeed>, time: impl Into<EgmClock>, ) -> Self
Create a sensor message containing a 6-DOF pose target with a cartesian speed reference.
The header timestamp is created from the time parameter.